@@ -6,8 +6,6 @@ describe 'gnocchi::statsd' do
     { :enabled             => true,
       :manage_service      => true,
       :resource_id         => '07f26121-5777-48ba-8a0b-d70468133dd9',
-      :user_id             => '07f26121-5777-48ba-8a0b-d70468133dd9',
-      :project_id          => '07f26121-5777-48ba-8a0b-d70468133dd9',
       :archive_policy_name => 'high',
       :flush_delay         => '200',
     }
@@ -28,8 +26,6 @@ describe 'gnocchi::statsd' do
 
     it 'configures gnocchi statsd' do
       is_expected.to contain_gnocchi_config('statsd/resource_id').with_value('07f26121-5777-48ba-8a0b-d70468133dd9')
-      is_expected.to contain_gnocchi_config('statsd/user_id').with_value('07f26121-5777-48ba-8a0b-d70468133dd9')
-      is_expected.to contain_gnocchi_config('statsd/project_id').with_value('07f26121-5777-48ba-8a0b-d70468133dd9')
       is_expected.to contain_gnocchi_config('statsd/archive_policy_name').with_value('high')
       is_expected.to contain_gnocchi_config('statsd/flush_delay').with_value('200')
     end
